package com.ruoyi.abuwx.controller.exam;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.abuwx.domain.exam.ExmExam;
import com.ruoyi.abuwx.service.exam.IExmExamService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 考试Controller
 * 
 * @author ruoyi
 * @date 2024-05-17
 */
@RestController
@RequestMapping("/system/exam")
public class ExmExamController extends BaseController
{
    @Autowired
    private IExmExamService exmExamService;

    /**
     * 查询考试列表
     */
    @PreAuthorize("@ss.hasPermi('system:exam:list')")
    @GetMapping("/list")
    public TableDataInfo list(ExmExam exmExam)
    {
        startPage();
        List<ExmExam> list = exmExamService.selectExmExamList(exmExam);
        return getDataTable(list);
    }

    /**
     * 导出考试列表
     */
    @PreAuthorize("@ss.hasPermi('system:exam:export')")
    @Log(title = "考试", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ExmExam exmExam)
    {
        List<ExmExam> list = exmExamService.selectExmExamList(exmExam);
        ExcelUtil<ExmExam> util = new ExcelUtil<ExmExam>(ExmExam.class);
        util.exportExcel(response, list, "考试数据");
    }

    /**
     * 获取考试详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:exam:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(exmExamService.selectExmExamById(id));
    }

    /**
     * 新增考试
     */
    @PreAuthorize("@ss.hasPermi('system:exam:add')")
    @Log(title = "考试", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ExmExam exmExam)
    {
        return toAjax(exmExamService.insertExmExam(exmExam));
    }

    /**
     * 修改考试
     */
    @PreAuthorize("@ss.hasPermi('system:exam:edit')")
    @Log(title = "考试", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ExmExam exmExam)
    {
        return toAjax(exmExamService.updateExmExam(exmExam));
    }

    /**
     * 删除考试
     */
    @PreAuthorize("@ss.hasPermi('system:exam:remove')")
    @Log(title = "考试", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(exmExamService.deleteExmExamByIds(ids));
    }
}
